/******************************************************************************/
/* Files to Include                                                           */
/******************************************************************************/

#if defined(__XC)
    #include <xc.h>         /* XC8 General Include File */
#elif defined(HI_TECH_C)
    #include <htc.h>        /* HiTech General Include File */
#endif

#include "mcc_generated_files/mcc.h"        /* System funct/params, like osc/peripheral config */


/******************************************************************************/
/* Main Program                                                               */
/******************************************************************************/

void writeDAC(uint8_t channel, uint8_t value)
{
    DAC_CS_SetLow();
    SPI_Exchange8bit(((channel & 1) << 1) | ((channel & 2) >> 1));
    SPI_Exchange8bit(value);
    DAC_CS_SetHigh();

    //Just to be safe
    asm("nop");asm("nop");asm("nop");asm("nop");
}

int16_t abs16(int16_t value)
{
    if (value < 0) return -value;
    return value;
}

adc_result_t X1, Y1, X2, Y2;

#define readStick(stick) stick = (ADC1_GetConversion(channel_##stick) >> 2) & 0xFF

#define adaptStickRange(stick)  if (stick < min ## stick) min ## stick = stick;    \
                                if (stick > max ## stick) max ## stick = stick;  

#define mapStick(stick) stick = (stick - min ## stick) * 255 / (max ## stick - min ## stick)

#define stickDeadzone(stick) if (abs16(stick - 128) < 20) stick = 128;

#define writeStick(channel, stick) writeDAC(channel, (uint8_t)(stick & 0xFF))

void main(void)
{
    int i = 0;
    int16_t centerX1, centerY1, centerX2, centerY2;
    int16_t minX1, maxX1, minY1, maxY1;
    int16_t minX2, maxX2, minY2, maxY2;

    SYSTEM_Initialize();

    //Wait a bit so that everything is stable
    INTCONbits.TMR0IF = 0;
    TMR0_Reload();
    while (!TMR0_HasOverflowOccured());

    //Read center sliders values
    X1 = 0; Y1 = 0; X2 = 0; Y2 = 0;
    for (i = 0; i < 16; i++)
    {
        X1 += (ADC1_GetConversion(channel_X1) >> 2) & 0xFF;
        Y1 += (ADC1_GetConversion(channel_Y1) >> 2) & 0xFF;
        X2 += (ADC1_GetConversion(channel_X2) >> 2) & 0xFF;
        Y2 += (ADC1_GetConversion(channel_Y2) >> 2) & 0xFF;
    }
    X1 >>= 4;
    Y1 >>= 4;
    X2 >>= 4;
    Y2 >>= 4;
    centerX1 = X1;
    centerY1 = Y1;
    centerX2 = X2;
    centerY2 = Y2;

    //Use a first guess for sliders ranges
    minX1 = centerX1 - 10; maxX1 = centerX1 + 10;
    minY1 = centerY1 - 10; maxY1 = centerY1 + 10;
    minX2 = centerX2 - 10; maxX2 = centerX2 + 10;
    minY2 = centerY2 - 10; maxY2 = centerY2 + 10;

    while(1)
    {
        //Read the slider values
        readStick(X1);
        readStick(Y1);
        readStick(X2);
        readStick(Y2);

        //Adapt ranges
        adaptStickRange(X1);
        adaptStickRange(Y1);
        adaptStickRange(X2);
        adaptStickRange(Y2);

        //Map sticks
        mapStick(X1);
        mapStick(Y1);
        mapStick(X2);
        mapStick(Y2);

        //Deadzone
        stickDeadzone(X1);
        stickDeadzone(Y1);
        stickDeadzone(X2);
        stickDeadzone(Y2);

        //Write slider positions to the DAC
        writeStick(0, X1);
        writeStick(1, Y1);
        writeStick(2, X2);
        writeStick(3, Y2);
    }

}

